@@ -2,7 +2,7 @@ import requests
 import json
 
 
-def get_Hbar_price():
+def get_Hbar_price(others=False):
     "doc: https://www.coingecko.com/api/documentations/v3#/"
     url = 'https://api.coingecko.com/api/v3/coins/hedera-hashgraph'
     params = {'localization': 'en',
@@ -13,5 +13,7 @@ def get_Hbar_price():
               'sparkline': 'false'}
     r = requests.get(url, params=params)
     data = r.json()
-    price_usd = data['market_data']['current_price']['usd']
-    return price_usd
+    if others:
+        return data['market_data']['current_price']
+    else:
+        return data['market_data']['current_price']['usd']
